@@ -117,13 +117,13 @@ is_close:{is_close}
             # TODO: 添加发送失败报警
             # 尝试重连, 这里不抛出异常, 等待服务端恢复, 允许丢失一些日志
             try:
-                time.sleep(60)
                 self.__reconnect()
                 __inner()
                 print('处理服务端崩溃成功.')
             except:
+                print('处理服务端崩溃失败.')
                 # DEBUG
-                raise
+                # raise
 
     def send(self, message=None):
         """
